=========
Reference
=========

Ballot
======

Ballot
------

.. autoclass:: whalrus.Ballot
    :members:

BallotOrder
-----------

.. autoclass:: whalrus.BallotOrder
    :members:

BallotLevels
------------

.. autoclass:: whalrus.BallotLevels
    :members:

BallotOneName
-------------

.. autoclass:: whalrus.BallotOneName
    :members:

BallotPlurality
---------------

.. autoclass:: whalrus.BallotPlurality
    :members:

BallotVeto
----------

.. autoclass:: whalrus.BallotVeto
    :members:

ConverterBallot
===============

ConverterBallot
---------------

.. autoclass:: whalrus.ConverterBallot
    :members:

ConverterBallotGeneral
----------------------

.. autoclass:: whalrus.ConverterBallotGeneral
    :members:

ConverterBallotToOrder
----------------------

.. autoclass:: whalrus.ConverterBallotToOrder
    :members:

ConverterBallotToStrictOrder
----------------------------

.. autoclass:: whalrus.ConverterBallotToStrictOrder
    :members:

ConverterBallotToPlurality
--------------------------

.. autoclass:: whalrus.ConverterBallotToPlurality
    :members:

ConverterBallotToVeto
---------------------

.. autoclass:: whalrus.ConverterBallotToVeto
    :members:

ConverterBallotToLevelsInterval
-------------------------------

.. autoclass:: whalrus.ConverterBallotToLevelsInterval
    :members:

ConverterBallotToLevelsRange
----------------------------

.. autoclass:: whalrus.ConverterBallotToLevelsRange
    :members:

ConverterBallotToLevelsListNumeric
----------------------------------

.. autoclass:: whalrus.ConverterBallotToLevelsListNumeric
    :members:

ConverterBallotToLevelsListNonNumeric
-------------------------------------

.. autoclass:: whalrus.ConverterBallotToLevelsListNonNumeric
    :members:

ConverterBallotToGrades
-----------------------

.. autoclass:: whalrus.ConverterBallotToGrades
    :members:

ConverterBallotToLevels
-----------------------

.. autoclass:: whalrus.ConverterBallotToLevels
    :members:

Elimination
===========

Elimination
-----------

.. autoclass:: whalrus.Elimination
    :members:

EliminationLast
---------------

.. autoclass:: whalrus.EliminationLast
    :members:

EliminationBelowAverage
-----------------------

.. autoclass:: whalrus.EliminationBelowAverage
    :members:

Matrix
======

Matrix
------

.. autoclass:: whalrus.Matrix
    :members:

MatrixWeightedMajority
----------------------

.. autoclass:: whalrus.MatrixWeightedMajority
    :members:

MatrixMajority
--------------

.. autoclass:: whalrus.MatrixMajority
    :members:

MatrixRankedPairs
-----------------

.. autoclass:: whalrus.MatrixRankedPairs
    :members:

Priority
========

Priority
--------

.. autoclass:: whalrus.Priority
    :members:

PriorityUnambiguous
-------------------

.. autoclass:: whalrus.PriorityUnambiguous
    :members:

PriorityAbstain
---------------

.. autoclass:: whalrus.PriorityAbstain
    :members:

PriorityAscending
-----------------

.. autoclass:: whalrus.PriorityAscending
    :members:

PriorityDescending
------------------

.. autoclass:: whalrus.PriorityDescending
    :members:

PriorityRandom
--------------

.. autoclass:: whalrus.PriorityRandom
    :members:

Profile
=======

.. autoclass:: whalrus.Profile
    :members:

Rule: In General
================

Rule
----

.. autoclass:: whalrus.Rule
    :members:

RuleScore
---------

.. autoclass:: whalrus.RuleScore
    :members:

RuleScoreNum
------------

.. autoclass:: whalrus.RuleScoreNum
    :members:

RuleScoreNumAverage
-------------------

.. autoclass:: whalrus.RuleScoreNumAverage
    :members:

RuleScoreNumRowSum
------------------

.. autoclass:: whalrus.RuleScoreNumRowSum
    :members:

RuleScorePositional
-------------------

.. autoclass:: whalrus.RuleScorePositional
    :members:

RuleIteratedElimination
-------------------------

.. autoclass:: whalrus.RuleIteratedElimination
    :members:

RuleSequentialElimination
-------------------------

.. autoclass:: whalrus.RuleSequentialElimination
    :members:

RuleSequentialTieBreak
----------------------

.. autoclass:: whalrus.RuleSequentialTieBreak
    :members:

Rule: In Particular
===================

RuleApproval
------------

.. autoclass:: whalrus.RuleApproval
    :members:

RuleBaldwin
-----------

.. autoclass:: whalrus.RuleBaldwin
    :members:

RuleBlack
---------

.. autoclass:: whalrus.RuleBlack
    :members:

RuleBorda
---------

.. autoclass:: whalrus.RuleBorda
    :members:

RuleBucklinByRounds
-------------------

.. autoclass:: whalrus.RuleBucklinByRounds
    :members:

RuleBucklinInstant
------------------

.. autoclass:: whalrus.RuleBucklinInstant
    :members:

RuleCondorcet
-------------

.. autoclass:: whalrus.RuleCondorcet
    :members:

RuleCoombs
----------

.. autoclass:: whalrus.RuleCoombs
    :members:

RuleCopeland
------------

.. autoclass:: whalrus.RuleCopeland
    :members:

RuleIRV
-------

.. autoclass:: whalrus.RuleIRV
    :members:

RuleKApproval
-------------

.. autoclass:: whalrus.RuleKApproval
    :members:

RuleKimRoush
------------

.. autoclass:: whalrus.RuleKimRoush
    :members:

RuleMajorityJudgment
--------------------

.. autoclass:: whalrus.RuleMajorityJudgment
    :members:

RuleMaximin
-----------

.. autoclass:: whalrus.RuleMaximin
    :members:

RuleNanson
----------

.. autoclass:: whalrus.RuleNanson
    :members:

RulePlurality
-------------

.. autoclass:: whalrus.RulePlurality
    :members:

RuleRangeVoting
---------------

.. autoclass:: whalrus.RuleRangeVoting
    :members:

RuleRankedPairs
---------------

.. autoclass:: whalrus.RuleRankedPairs
    :members:

RuleSimplifiedDodgson
---------------------

.. autoclass:: whalrus.RuleSimplifiedDodgson
    :members:

RuleTwoRound
------------

.. autoclass:: whalrus.RuleTwoRound
    :members:

RuleVeto
--------

.. autoclass:: whalrus.RuleVeto
    :members:

Scale
=====

Scale
-----

.. autoclass:: whalrus.Scale
    :members:

ScaleFromList
-------------

.. autoclass:: whalrus.ScaleFromList
    :members:

ScaleFromSet
------------

.. autoclass:: whalrus.ScaleFromSet
    :members:

ScaleRange
----------

.. autoclass:: whalrus.ScaleRange
    :members:

ScaleInterval
-------------

.. autoclass:: whalrus.ScaleInterval
    :members:

Scorer
======

Scorer
------

.. autoclass:: whalrus.Scorer
    :members:

ScorerBorda
-----------

.. autoclass:: whalrus.ScorerBorda
    :members:

ScorerBucklin
-------------

.. autoclass:: whalrus.ScorerBucklin
    :members:

ScorerLevels
------------

.. autoclass:: whalrus.ScorerLevels
    :members:

ScorerPlurality
---------------

.. autoclass:: whalrus.ScorerPlurality
    :members:

ScorerPositional
----------------

.. autoclass:: whalrus.ScorerPositional
    :members:

ScorerVeto
----------

.. autoclass:: whalrus.ScorerVeto
    :members:

Utils
=====

.. autoclass:: whalrus.cached_property
    :members:

.. autofunction:: whalrus.convert_number

.. autoclass:: whalrus.DeleteCacheMixin
    :members:

.. autofunction:: whalrus.dict_to_items

.. autofunction:: whalrus.dict_to_str

.. autofunction:: whalrus.my_division

.. autoclass:: whalrus.NiceSet
    :members:

.. autoclass:: whalrus.NiceDict
    :members:

.. autofunction:: whalrus.parse_weak_order

.. autofunction:: whalrus.set_to_list

.. autofunction:: whalrus.set_to_str

.. autofunction:: whalrus.take_closest
